-- by modelleicher
-- www.schwabenmodding.bplaced.net

-- adds additional particle system 
-- particle system emits if the engine load is above a certain threshold (psThreshold value)
-- maxMotorLoad, the max. value motorLoad can reach witch the particular vehicle (use vehicle debug rendering to figure that value out)


newExhaustEffects = {};

function newExhaustEffects.prerequisitesPresent(specializations)
    return true;
end;

function newExhaustEffects:load(savegame)
    self.nrep = {}; -- all variables will be stored in this table to prevent interference with other scripts 
    self.nrep.psThreshold = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.newExhaustEffects#psThreshold"), 0.85);
    self.nrep.maxMotorLoad = 0;
    
    
    self.nrep.ps = {};
    self.nrep.psCnt = Utils.getNoNil(getXMLInt(self.xmlFile, "vehicle.newExhaustEffects#psCount"), false);
    if self.nrep.psCnt == false then 
         ParticleUtil.loadParticleSystem(self.xmlFile, self.nrep.ps, "vehicle.newExhaustEffects.particle", self.components, false, nil, self.baseDirectory)
    else
        for i=1, self.nrep.psCnt do
            local ps = {};
             ParticleUtil.loadParticleSystem(self.xmlFile, ps, "vehicle.newExhaustEffects.particle"..i, self.components, false, nil, self.baseDirectory)
            table.insert(self.nrep.ps, ps);
        end;
    end;
            
end;


function newExhaustEffects:update(dt)    
    if self:getIsActive() and self.isMotorStarted then        
        self.nrep.maxMotorLoad = math.max(self.motor.motorLoad, self.nrep.maxMotorLoad); -- automatically define the range for the max motor load
        local mLoad =  self.motor.motorLoad / self.nrep.maxMotorLoad; -- converting the individual motor load to 0-1 range value     
        if mLoad > self.nrep.psThreshold then
            if self.nrep.psCnt == false then
                ParticleUtil.setEmittingState(self.nrep.ps, true);
            else
                for i=1, self.nrep.psCnt do
                    ParticleUtil.setEmittingState(self.nrep.ps[i], true);
                end;
            end;
        else
            if self.nrep.psCnt == false then
                ParticleUtil.setEmittingState(self.nrep.ps, false)
            else
                for i=1, self.nrep.psCnt do
                    ParticleUtil.setEmittingState(self.nrep.ps[i], false);
                end;
            end;                
        end;
    end;
end;
function newExhaustEffects:delete()
    if self.nrep.ps ~= nil then
        if self.nrep.psCnt == false then
            ParticleUtil.deleteParticleSystem(self.nrep.ps);
        else
            for i=1, self.nrep.psCnt do
                ParticleUtil.deleteParticleSystem(self.nrep.ps[i]);
            end;
        end;
    end;
end;
function newExhaustEffects:onLeave()
    if self.nrep.ps then
        if self.nrep.psCnt == false then
            ParticleUtil.setEmittingState(self.nrep.ps, false);
        else
            for i=1, self.nrep.psCnt do
                ParticleUtil.setEmittingState(self.nrep.ps[i], false);
            end;
        end;
    end;
end;
function newExhaustEffects:mouseEvent(posX, posY, isDown, isUp, button)
end;
function newExhaustEffects:keyEvent(unicode, sym, modifier, isDown)
end;
function newExhaustEffects:draw()
end;
